@@ -1,7 +1,4 @@
 begin
-  require 'bundler'
-  Bundler.require
-
   if ENV['COVERAGE']
     require 'simplecov'
     SimpleCov.start do
@@ -9,14 +6,15 @@ begin
       add_filter '/vendor/'
     end
   end
-rescue LoadError
+
+  require 'bundler'
+  Bundler.require
+rescue LoadError, Bundler::GemNotFound
 end
 
 require 'test/unit'
 require 'power_assert'
 require 'ripper'
-require 'byebug'
-require_relative 'test_core_ext_helper'
 
 module PowerAssertTestHelper
   class << self
@@ -53,4 +51,12 @@ module PowerAssertTestHelper
       pa.message
     end
   end
+
+  def strip_color(str)
+    str.gsub(/(\001)?\e\[.*?(\d)+m(\002)?/, '')
+  end
 end
+
+RubyVM::InstructionSequence.compile_option = {
+  specialized_instruction: true
+}
